@@ -1,20 +1,15 @@
 import copy
 import datetime
 import functools
-import io
 import json
 import logging
 import math
 import os
-import pprint
-import re
-import tempfile
 import time
 
 import lxml.etree
 import numpy as np
 import pandas as pd
-import pkg_resources
 import plotly.express as px
 import plotly.graph_objects as go
 import wotpy.wot.consumed.thing
@@ -25,7 +20,7 @@ from wotemu.report.components.container import ContainerComponent
 from wotemu.report.components.figure_block import FigureBlockComponent
 from wotemu.report.components.task_list import TaskListComponent
 from wotemu.report.components.task_section import TaskSectionComponent
-from wotemu.report.utils import get_base_template, shorten_task_name
+from wotemu.report.utils import shorten_task_name
 from wotpy.protocols.enums import InteractionVerbs
 
 _MIN_HEIGHT = 400
@@ -263,7 +258,7 @@ class ReportBuilder:
 
         return 0 if df_where.empty else (df_where.iloc[0]["len"] / 1024.0)
 
-    async def build_service_traffic_figure(self, inbound, colorscale="Portland", height_task=50):
+    async def build_service_traffic_figure(self, inbound, colorscale="Portland", height_task=70):
         df = await self._get_service_traffic_df(inbound=inbound)
 
         if df.empty:
@@ -541,7 +536,7 @@ class ReportBuilder:
 
         return fig
 
-    async def build_cpu_ranking_figure(self, height_task=32, height_facet=50):
+    async def build_cpu_ranking_figure(self, height_task=45, height_facet=50):
         task_keys = await self._get_tasks()
 
         if not task_keys or len(task_keys) == 0:
@@ -589,7 +584,7 @@ class ReportBuilder:
                 y=df_model["task_short"],
                 name=model)
 
-            fig.append_trace(trace, row=(idx + 1), col=1)
+            fig.add_trace(trace, row=(idx + 1), col=1)
 
         fig.update_traces(orientation="h")
 
@@ -606,7 +601,7 @@ class ReportBuilder:
 
         return fig
 
-    async def build_mem_ranking_figure(self, height_task=32):
+    async def build_mem_ranking_figure(self, height_task=45):
         task_keys = await self._get_tasks()
 
         if not task_keys or len(task_keys) == 0:
@@ -641,7 +636,7 @@ class ReportBuilder:
 
         return fig
 
-    async def build_task_timeline_figure(self, height_task=30):
+    async def build_task_timeline_figure(self, height_task=45):
         df_snap = await self._get_snapshot_df()
 
         df_snap["finish"] = np.where(
